@@ -3,7 +3,7 @@ package AI::Genetic::Pro::Selection::Roulette;
 use warnings;
 use strict;
 #use Data::Dumper; $Data::Dumper::Sortkeys = 1;
-use List::Util qw(sum);
+use List::Util qw(sum min);
 use List::MoreUtils qw(first_index);
 #=======================================================================
 sub new { bless \$_[0], $_[0]; }
@@ -14,13 +14,14 @@ sub run {
 	my ($fitness) = ($ga->_fitness);
 	my (@parents, @elders);
 	#-------------------------------------------------------------------
-	my $total = sum(values %$fitness) + 1; $total ||= 1;
 	my $count = $#{$ga->chromosomes};
+	my $const = min values %$fitness;
+	$const = $const < 0 ? abs($const) : 0;
+	my $total = sum( map { $_ < 0 ? $_ + $const : $_ } values %$fitness);
 	
-	# elders 
+	# elders
 	for my $idx (0..$count){
-		my $cnt = int ( ( $fitness->{$idx} / $total ) * $count);
-		push @elders, $idx for 1..$cnt;
+		push @elders, $idx for 1..int((($fitness->{$idx} + $const) / $total) * $count);
 	}
 	
 	if((my $add = $count - scalar @elders) > 0){
@@ -38,7 +39,7 @@ sub run {
 			push @parents, pack 'I*', @group;
 		}
 	}
-	
+
 	#-------------------------------------------------------------------
 	return \@parents;
 }
